@@ -1,20 +1,16 @@
 #include "fast_library.hpp"
-#include <arpa/inet.h>
 #include <fstream>
 #include <iostream>
-#include <net/if.h>
-#include <netdb.h>
-#include <netinet/in.h>
-#include <stdint.h>
-#include <stdlib.h> // atoi
-#include <sys/ioctl.h>
-#include <sys/socket.h>
-#include <sys/stat.h>
-#include <sys/types.h>
-#include <unistd.h>
 
+// Windows does not use ioctl
+#ifndef _WIN32
+#include <sys/ioctl.h>
+#endif
+
+#ifndef _WIN32
 // For uname function
 #include <sys/utsname.h>
+#endif
 
 #include "all_logcpp_libraries.hpp"
 
@@ -35,6 +31,9 @@
 #include <capnp/serialize-packed.h>
 #endif
 
+#include <boost/algorithm/string.hpp>
+#include <boost/regex.hpp>
+
 boost::regex regular_expression_cidr_pattern("^\\d+\\.\\d+\\.\\d+\\.\\d+\\/\\d+$");
 boost::regex regular_expression_host_pattern("^\\d+\\.\\d+\\.\\d+\\.\\d+$");
 
@@ -43,14 +42,6 @@ int convert_string_to_integer(std::string line) {
     return atoi(line.c_str());
 }
 
-uint32_t convert_ip_as_string_to_uint(std::string ip) {
-    struct in_addr ip_addr;
-    inet_aton(ip.c_str(), &ip_addr);
-
-    // in network byte order
-    return ip_addr.s_addr;
-}
-
 std::string convert_ip_as_uint_to_string(uint32_t ip_as_integer) {
     struct in_addr ip_addr;
     ip_addr.s_addr = ip_as_integer;
@@ -65,43 +56,44 @@ std::string convert_int_to_string(int value) {
     return out.str();
 }
 
-// BE AWARE! WE USE NON STANDARD SUBNET_T HERE! WE USE NON CIDR MASK HERE!
-subnet_cidr_mask_t convert_subnet_from_string_to_binary(std::string subnet_cidr) {
+// Converts IP address in cidr form 11.22.33.44/24 to our representation
+bool convert_subnet_from_string_to_binary_with_cidr_format_safe(const std::string& subnet_cidr, subnet_cidr_mask_t& subnet_cidr_mask) {
+    if (subnet_cidr.empty()) {
+        return false;
+    }
+
+    // It's not a cidr mask
+    if (!is_cidr_subnet(subnet_cidr)) {
+        return false;
+    }
+
     std::vector<std::string> subnet_as_string;
+
     split(subnet_as_string, subnet_cidr, boost::is_any_of("/"), boost::token_compress_on);
 
-    unsigned int cidr = convert_string_to_integer(subnet_as_string[1]);
-
-    uint32_t subnet_as_int = convert_ip_as_string_to_uint(subnet_as_string[0]);
-
-    return subnet_cidr_mask_t(subnet_as_int, cidr);
-}
-
-// TODO: very bad code without result checks!!! Get rid all functions which are using it
-// But this code is pretty handy in tests code
-subnet_cidr_mask_t convert_subnet_from_string_to_binary_with_cidr_format(std::string subnet_cidr) {
-    std::vector<std::string> subnet_as_string;
-    split(subnet_as_string, subnet_cidr, boost::is_any_of("/"), boost::token_compress_on);
-
-    // Return zero subnet in this case
     if (subnet_as_string.size() != 2) {
-        return subnet_cidr_mask_t();
+        return false;
     }
 
-    unsigned int cidr = convert_string_to_integer(subnet_as_string[1]);
+    uint32_t subnet_as_int = 0;
 
-    uint32_t subnet_as_int = convert_ip_as_string_to_uint(subnet_as_string[0]);
+    bool ip_to_integer_convresion_result = convert_ip_as_string_to_uint_safe(subnet_as_string[0], subnet_as_int);
 
-    return subnet_cidr_mask_t(subnet_as_int, cidr);
-}
-
-void copy_networks_from_string_form_to_binary(std::vector<std::string> networks_list_as_string,
-                                              std::vector<subnet_cidr_mask_t>& our_networks) {
-    for (std::vector<std::string>::iterator ii = networks_list_as_string.begin(); ii != networks_list_as_string.end(); ++ii) {
-
-        subnet_cidr_mask_t current_subnet = convert_subnet_from_string_to_binary(*ii);
-        our_networks.push_back(current_subnet);
+    if (!ip_to_integer_convresion_result) {
+        return false;
     }
+
+    int cidr = 0;
+
+    bool ip_conversion_result = convert_string_to_any_integer_safe(subnet_as_string[1], cidr);
+
+    if (!ip_conversion_result) {
+        return false;
+    }
+
+    subnet_cidr_mask = subnet_cidr_mask_t(subnet_as_int, cidr);
+
+    return true;
 }
 
 std::string convert_subnet_to_string(subnet_cidr_mask_t my_subnet) {
@@ -452,6 +444,8 @@ bool serialize_simple_packet_to_json(const simple_packet_t& packet, nlohmann::js
     }
 
     try {
+        // We use arrival_time as traffic telemetry protocols do not provide this time in a reliable manner
+        json_packet["timestamp"] = packet.arrival_time;
 
         json_packet["ip_version"] = protocol_version;
 
@@ -721,13 +715,13 @@ interfaces_list_t get_interfaces_list() {
 }
 
 // Get all IPs for interface: main IP and aliases
-ip_addresses_list_t get_ip_list_for_interface(std::string interface) {
+ip_addresses_list_t get_ip_list_for_interface(const std::string& interface_name) {
     ip_addresses_list_t ip_list;
 
     std::string error_text;
     std::vector<std::string> output_list;
 
-    bool exec_result = exec("ip address show dev " + interface, output_list, error_text);
+    bool exec_result = exec("ip address show dev " + interface_name, output_list, error_text);
 
     if (!exec_result) {
         return ip_list;
@@ -790,26 +784,6 @@ std::string convert_prefix_to_string_representation(prefix_t* prefix) {
     return address + "/" + convert_int_to_string(prefix->bitlen);
 }
 
-std::string find_subnet_by_ip_in_string_format(patricia_tree_t* patricia_tree, std::string ip) {
-    patricia_node_t* found_patrica_node = NULL;
-
-    // Convert IP to integer
-    uint32_t client_ip = convert_ip_as_string_to_uint(ip);
-
-    prefix_t prefix_for_check_adreess;
-    prefix_for_check_adreess.add.sin.s_addr = client_ip;
-    prefix_for_check_adreess.family         = AF_INET;
-    prefix_for_check_adreess.bitlen         = 32;
-
-    found_patrica_node = patricia_search_best2(patricia_tree, &prefix_for_check_adreess, 1);
-
-    if (found_patrica_node != NULL) {
-        return convert_prefix_to_string_representation(found_patrica_node->prefix);
-    } else {
-        return "";
-    }
-}
-
 // It could not be on start or end of the line
 boost::regex ipv6_address_compression_algorithm("(0000:){2,}");
 
@@ -960,7 +934,6 @@ std::string get_direction_name(direction_t direction_value) {
     return direction_name;
 }
 
-// We haven't this code for FreeBSD yet
 #ifdef __linux__
 bool manage_interface_promisc_mode(std::string interface_name, bool switch_on) {
     extern log4cpp::Category& logger;
@@ -1232,6 +1205,9 @@ bool convert_hex_as_string_to_uint(std::string hex, uint32_t& value) {
     return ss.fail();
 }
 
+
+#ifdef __linux__
+// We use this logic only from AF_PACKET and we clearly have no reasons to maintain cross platform portability for it
 // Get interface number by name
 bool get_interface_number_by_device_name(int socket_fd, std::string interface_name, int& interface_number) {
     struct ifreq ifr;
@@ -1243,27 +1219,21 @@ bool get_interface_number_by_device_name(int socket_fd, std::string interface_na
 
     strncpy(ifr.ifr_name, interface_name.c_str(), sizeof(ifr.ifr_name));
 
-/* Attempt to use SIOCGIFINDEX if present. */
-#ifdef SIOCGIFINDEX
     if (ioctl(socket_fd, SIOCGIFINDEX, &ifr) == -1) {
         return false;
     }
 
     interface_number = ifr.ifr_ifindex;
-#else
-    /* Fallback to if_nametoindex(3) otherwise. */
-    interface_number = if_nametoindex(interface_name.c_str());
-    if (interface_number == 0) return false;
-#endif /* SIOCGIFINDEX */
     return true;
 }
 
+#endif
 
-#if defined(__APPLE__)
+#if defined(__APPLE__) || defined(_WIN32)
 bool set_boost_process_name(boost::thread* thread, const std::string& process_name) {
     extern log4cpp::Category& logger;
 
-    logger << log4cpp::Priority::ERROR << "Apple platforms do not support thread name changes";
+    logger << log4cpp::Priority::ERROR << "We do not support custom thread names on this platform";
     return false;
 }
 
@@ -2226,6 +2196,12 @@ std::string get_virtualisation_method() {
     return boost::algorithm::to_lower_copy(output[0]);
 }
 
+#ifdef _WIN32
+bool get_kernel_version(std::string& kernel_version) {
+    kernel_version = "windows";
+    return true;
+}
+#else
 // Get linux kernel version in form: 3.19.0-25-generic
 bool get_kernel_version(std::string& kernel_version) {
     struct utsname current_utsname;
@@ -2241,6 +2217,7 @@ bool get_kernel_version(std::string& kernel_version) {
 
     return true;
 }
+#endif
 
 // Returns all CPU flags in vector
 bool get_cpu_flags(std::vector<std::string>& flags) {
@@ -2360,6 +2337,23 @@ std::string country_static_string_to_dynamic_string(const boost::beast::static_s
     return country_code_dynamic_string;
 }
 
+#ifdef _WIN32
+// We have no inet_aton on Windows but we do have inet_pton https://learn.microsoft.com/en-us/windows/win32/api/ws2tcpip/nf-ws2tcpip-inet_pton
+// Convert IP in string representation to uint32_t in big endian (network byte order)
+// I think we can switch to using pton for Linux and other *nix too but we need to do careful testing including performance evaluation before
+bool convert_ip_as_string_to_uint_safe(const std::string& ip, uint32_t& ip_as_integer) {
+    struct in_addr ip_addr;
+
+    // Both Windows and Linux return 1 in case of success
+    if (inet_pton(AF_INET, ip.c_str(), &ip_addr) != 1) {
+        return false;
+    }
+
+    // in network byte order
+    ip_as_integer = ip_addr.s_addr;
+    return true;
+}
+#else
 // Convert IP in string representation to uint32_t in big endian (network byte order)
 bool convert_ip_as_string_to_uint_safe(const std::string& ip, uint32_t& ip_as_integer) {
     struct in_addr ip_addr;
@@ -2374,3 +2368,4 @@ bool convert_ip_as_string_to_uint_safe(const std::string& ip, uint32_t& ip_as_in
     ip_as_integer = ip_addr.s_addr;
     return true;
 }
+#endif
