@@ -5,27 +5,16 @@
 #include <iostream>
 #include <map>
 #include <sstream>
-#include <stdint.h>
 #include <string>
 
-#include <sys/types.h>
-#include <unistd.h>
 #include <utility>
 #include <vector>
 
-#include <boost/regex.hpp>
 #include <boost/thread.hpp>
-#include <boost/thread/mutex.hpp>
-
 #include "nlohmann/json.hpp"
 
-// Boost libs
-#include <boost/algorithm/string.hpp>
-
 #include "libpatricia/patricia.hpp"
 
-#include "fast_endianless.hpp"
-
 #include "fastnetmon_networks.hpp"
 
 #define TCP_FIN_FLAG_SHIFT 1
@@ -40,14 +29,13 @@ typedef std::vector<std::string> interfaces_list_t;
 typedef std::vector<std::string> ip_addresses_list_t;
 
 ip_addresses_list_t get_local_ip_v4_addresses_list();
-ip_addresses_list_t get_ip_list_for_interface(std::string interface);
+ip_addresses_list_t get_ip_list_for_interface(const std::string& interface_name);
 interfaces_list_t get_interfaces_list();
 
 bool store_data_to_graphite(unsigned short int graphite_port, std::string graphite_host, graphite_data_t graphite_data);
 std::string get_protocol_name_by_number(unsigned int proto_number);
 uint64_t convert_speed_to_mbps(uint64_t speed_in_bps);
 bool exec(const std::string& cmd, std::vector<std::string>& output_list, std::string& error_text);
-uint32_t convert_ip_as_string_to_uint(std::string ip);
 std::string convert_ip_as_uint_to_string(uint32_t ip_as_integer);
 std::string convert_int_to_string(int value);
 std::string print_ipv6_address(const struct in6_addr& ipv6_address);
@@ -77,8 +65,6 @@ std::string get_printable_protocol_name(unsigned int protocol);
 std::string get_net_address_from_network_as_string(std::string network_cidr_format);
 std::string print_time_t_in_fastnetmon_format(time_t current_time);
 unsigned int get_cidr_mask_from_network_as_string(std::string network_cidr_format);
-void copy_networks_from_string_form_to_binary(std::vector<std::string> networks_list_as_string,
-                                              std::vector<subnet_cidr_mask_t>& our_networks);
 int convert_string_to_integer(std::string line);
 
 bool print_pid_to_file(pid_t pid, std::string pid_path);
@@ -90,15 +76,14 @@ direction_t
 get_packet_direction_ipv6(patricia_tree_t* lookup_tree, struct in6_addr src_ipv6, struct in6_addr dst_ipv6, subnet_ipv6_cidr_mask_t& subnet);
 
 std::string convert_prefix_to_string_representation(prefix_t* prefix);
-std::string find_subnet_by_ip_in_string_format(patricia_tree_t* patricia_tree, std::string ip);
 std::string convert_subnet_to_string(subnet_cidr_mask_t my_subnet);
 std::string get_direction_name(direction_t direction_value);
-subnet_cidr_mask_t convert_subnet_from_string_to_binary(std::string subnet_cidr);
 std::vector<std::string> split_strings_to_vector_by_comma(std::string raw_string);
-subnet_cidr_mask_t convert_subnet_from_string_to_binary_with_cidr_format(std::string subnet_cidr);
+bool convert_subnet_from_string_to_binary_with_cidr_format_safe(const std::string& subnet_cidr, subnet_cidr_mask_t& subnet_cidr_mask);
 
 #ifdef __linux__
 bool manage_interface_promisc_mode(std::string interface_name, bool switch_on);
+bool get_interface_number_by_device_name(int socket_fd, std::string interface_name, int& interface_number);
 #endif
 
 bool ip_belongs_to_patricia_tree_ipv6(patricia_tree_t* patricia_tree, struct in6_addr client_ipv6_address);
@@ -110,7 +95,6 @@ std::string serialize_statistic_counters_about_attack(attack_details_t& current_
 
 std::string dns_lookup(std::string domain_name);
 bool store_data_to_stats_server(unsigned short int graphite_port, std::string graphite_host, std::string buffer_as_string);
-bool get_interface_number_by_device_name(int socket_fd, std::string interface_name, int& interface_number);
 
 bool set_boost_process_name(boost::thread* thread, const std::string& process_name);
 std::string convert_subnet_to_string(subnet_cidr_mask_t my_subnet);
