@@ -11,12 +11,11 @@
 #include "../abstract_subnet_counters.hpp"
 
 extern log4cpp::Category& logger;
-extern struct timeval graphite_thread_execution_time;
 extern map_of_vector_counters_t SubnetVectorMapSpeed;
 extern map_of_vector_counters_t SubnetVectorMapSpeedAverage;
 extern uint64_t incoming_total_flows_speed;
 extern uint64_t outgoing_total_flows_speed;
-extern abstract_subnet_counters_t<subnet_cidr_mask_t> ipv4_network_counters;
+extern abstract_subnet_counters_t<subnet_cidr_mask_t, subnet_counter_t> ipv4_network_counters;
 extern total_speed_counters_t total_counters_ipv4;
 extern total_speed_counters_t total_counters_ipv6;
 
@@ -166,8 +165,8 @@ bool push_network_traffic_counters_to_graphite() {
     std::vector<std::pair<subnet_cidr_mask_t, subnet_counter_t>> speed_elements;
     ipv4_network_counters.get_all_non_zero_average_speed_elements_as_pairs(speed_elements);
 
-    for (const auto& itr: speed_elements) {
-        const subnet_counter_t* speed                            = &itr.second;
+    for (const auto& itr : speed_elements) {
+        const subnet_counter_t* speed                   = &itr.second;
         std::string subnet_as_string_as_dash_delimiters = convert_subnet_to_string(itr.first);
 
         // Replace dots by dashes
@@ -205,8 +204,7 @@ void graphite_push_thread() {
     while (true) {
         boost::this_thread::sleep(boost::posix_time::seconds(graphite_push_period));
 
-        struct timeval start_calc_time;
-        gettimeofday(&start_calc_time, NULL);
+        std::chrono::steady_clock::time_point start_time = std::chrono::steady_clock::now();
 
         // First of all push total counters to Graphite
         push_total_traffic_counters_to_graphite();
@@ -217,12 +215,8 @@ void graphite_push_thread() {
         // Push per host counters to graphite
         push_hosts_traffic_counters_to_graphite();
 
-        struct timeval end_calc_time;
-        gettimeofday(&end_calc_time, NULL);
+        std::chrono::duration<double> diff = std::chrono::steady_clock::now() - start_time;
 
-        timeval_subtract(&graphite_thread_execution_time, &end_calc_time, &start_calc_time);
-
-        logger << log4cpp::Priority::DEBUG << "Graphite data pushed in: " << graphite_thread_execution_time.tv_sec
-               << " sec " << graphite_thread_execution_time.tv_usec << " microseconds\n";
+        logger << log4cpp::Priority::DEBUG << "Graphite data pushed in: " << diff.count() << " seconds";
     }
 }
